=======
Credits
=======

Project Leader
--------------

* Mohammad Ganjtabesh (Director of `CNRL <https://cnrl.ut.ac.ir>`_) <mgtabesh@ut.ac.ir>

Development Leader
------------------

* Ashena Gorgan Mohammadi <ashenatena@gmail.com>

Contributors
------------

* Ali Rahimi <saeed.ali.rahimi@gmail.com>
* Amir H. Ebrahimi <amirhosseinebrahimi77@gmail.com>

**Note:** All benchmark codes are provided by Ali Rahimi & Marius Vieth.
